@@ -31,32 +31,37 @@ to analyze this data later on, e.g., using Metrics-Wallet or Metrics-Studio.
 """
 
 
-from typing import Any, Iterable
+from typing import Any, Iterable, Optional, Tuple
+
+from jsonpickle import decode as load_json
 
 from metrics.core.model import Campaign
 
-from metrics.scalpel.config import read_configuration
+from metrics.scalpel.config import read_configuration, ScalpelConfiguration
 from metrics.scalpel.listener import CampaignParserListener
 from metrics.scalpel.parser import create_parser
 
 
-def read_campaign(input_file: str) -> Campaign:
+def read_campaign(input_file: str) -> Tuple[Campaign, Optional[ScalpelConfiguration]]:
     """
     Reads the data about a campaign from the given input file.
 
     :param input_file: The input file describing the campaign.
 
-    :return: The read campaign.
+    :return: The read campaign and the configuration of this campaign, if any.
 
     :raises ValueError: If the input file does not have a recognized format.
     """
     if input_file.endswith('.yml') or input_file.endswith('.yaml'):
         return read_yaml(input_file)
 
-    raise ValueError(f'Unrecognized campaign format for file {input_file}')
+    if input_file.endswith('.json'):
+        return read_json(input_file), None
+
+    raise ValueError(f'Unrecognized campaign format for file "{input_file}"')
 
 
-def read_yaml(yaml_configuration: str) -> Campaign:
+def read_yaml(yaml_configuration: str) -> Tuple[Campaign, ScalpelConfiguration]:
     """
     Reads the data about a campaign following the configuration described in
     the given YAML file.
@@ -64,36 +69,49 @@ def read_yaml(yaml_configuration: str) -> Campaign:
     :param yaml_configuration: The path of the YAML file describing Scalpel's
                                configuration.
 
-    :return: The read campaign.
+    :return: The read campaign and the configuration of this campaign.
     """
     parser_listener = CampaignParserListener()
     configuration = read_configuration(yaml_configuration, parser_listener)
     campaign_parser = create_parser(configuration, parser_listener)
     for file in configuration.get_main_file():
         campaign_parser.parse_file(file)
-    return parser_listener.get_campaign()
+    return parser_listener.get_campaign(), configuration
 
 
-def convert_object(yaml_configuration: str, iterable: Iterable[Any]) -> Campaign:
+def read_json(json_file: str) -> Campaign:
     """
-    Convert the data stored in the given iterabl object following the
+    Reads a campaign that has been serialized in a JSON file.
+
+    :param json_file: The path of the JSON file to read the campaign from.
+
+    :return: The read campaign.
+    """
+    with open(json_file, 'r') as json_campaign:
+        return load_json(json_campaign.read())
+
+
+def read_object(yaml_configuration: str, campaign: Iterable[Any]) -> Tuple[Campaign, ScalpelConfiguration]:
+    """
+    Reads the data stored in the given iterable object following the
     configuration described in the given YAML file.
 
     :param yaml_configuration: The path of the YAML file describing Scalpel's
                                configuration.
-    :param iterable: The object to iterate over so as to get the data about the
+    :param campaign: The object to iterate over so as to get the data about the
                      campaign.
-                     Each element encountered during the iteration must define
-                     an "items()" method returning a set of key-value pairs
-                     (such as dictionaries or rows in a data-frame, for instance.
+                     Each element encountered during the iteration is supposed to
+                     represent an experiment, and must define an "items()" method
+                     returning a set of key-value pairs (such as dictionaries or
+                     rows in a data-frame, for instance).
 
-    :return: The read campaign.
+    :return: The read campaign and the configuration of this campaign.
     """
-    campaign_parser_listener = CampaignParserListener()
-    read_configuration(yaml_configuration, campaign_parser_listener)
-    for element in iterable:
-        campaign_parser_listener.start_experiment()
-        for key, value in element.items():
-            campaign_parser_listener.log_data(key, value)
-        campaign_parser_listener.end_experiment()
-    return campaign_parser_listener.get_campaign()
+    parser_listener = CampaignParserListener()
+    configuration = read_configuration(yaml_configuration, parser_listener)
+    for experiment in campaign:
+        parser_listener.start_experiment()
+        for key, value in experiment.items():
+            parser_listener.log_data(key, value)
+        parser_listener.end_experiment()
+    return parser_listener.get_campaign(), configuration
